Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(894)

Unified Diff: third_party/WebKit/Source/platform/heap/ThreadState.h

Issue 2690943009: Move postGC out of CrossThreadPersistentRegion::LockScope (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/heap/ThreadState.h
diff --git a/third_party/WebKit/Source/platform/heap/ThreadState.h b/third_party/WebKit/Source/platform/heap/ThreadState.h
index 8769d2b77cfee3537285069420ecde2b432b98d7..451a17d85c15ae851844cdae2043ec45215789cb 100644
--- a/third_party/WebKit/Source/platform/heap/ThreadState.h
+++ b/third_party/WebKit/Source/platform/heap/ThreadState.h
@@ -230,8 +230,9 @@ class PLATFORM_EXPORT ThreadState {
//
// 1) preGC() is called.
// 2) ThreadHeap::collectGarbage() is called. This marks live objects.
// 3) postGC() is called. This does thread-local weak processing,
// pre-finalization, eager sweeping and heap compaction.
// 4) Lazy sweeping sweeps heaps incrementally. completeSweep() may be called
// to complete the sweeping.
// 5) postSweep() is called.
@@ -245,6 +246,7 @@ class PLATFORM_EXPORT ThreadState {
void preGC();
void postGC(BlinkGC::GCType);
void completeSweep();
+ void preSweep(BlinkGC::GCType);
void postSweep();
// makeConsistentForMutator() drops marks from marked objects and rebuild
// free lists. This is called after taking a snapshot and before resuming
@@ -230,8 +230,9 @@ class PLATFORM_EXPORT ThreadState {
// 1) preGC() is called.
// 2) ThreadHeap::collectGarbage() is called. This marks live objects.
- // 3) postGC() is called. This does thread-local weak processing,
- // pre-finalization, eager sweeping and heap compaction.
+ // 3) postGC() is called. This does thread-local weak processing.
+ // 4) preSweep() is called. This does pre-finalization, eager sweeping and
+ // heap compaction.
// 4) Lazy sweeping sweeps heaps incrementally. completeSweep() may be called
// to complete the sweeping.
« no previous file with comments | « third_party/WebKit/Source/platform/heap/HeapTest.cpp ('k') | third_party/WebKit/Source/platform/heap/ThreadState.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698